@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Log4perl qw(:easy);
 
-our $VERSION    = "0.03";
+our $VERSION    = "0.04";
 our $DB_VERSION = "1.1";
 
 ###########################################
@@ -136,6 +136,27 @@ sub try_push {
     return $ret;
 }
 
+###########################################
+sub reset_key {
+###########################################
+    my($self, %options) = @_;
+
+    if(exists $options{key}) {
+        DEBUG "Resetting count for $options{key}";
+    } else {
+        DEBUG "Resetting count for keyless item";
+    }
+
+    $self->lock();
+
+    $self->{data} = $self->{db}->load();
+    my $ret = $self->{data}->{chain}->reset_key(%options);
+    $self->{db}->save( $self->{data} );
+
+    $self->unlock();
+    return $ret;
+}
+
 ###########################################
 sub buckets_dump {
 ###########################################
@@ -196,6 +217,8 @@ package Data::Throttler::BucketChain;
 ###########################################
 use Log::Log4perl qw(:easy);
 
+our $DEFAULT_KEY = "_default";
+
 ###########################################
 sub new {
 ###########################################
@@ -428,7 +451,7 @@ sub try_push {
 ###########################################
     my($self, %options) = @_;
 
-    my $key = "_default";
+    my $key = $DEFAULT_KEY;
     $key = $options{key} if defined $options{key};
 
     my $time = time();
@@ -467,6 +490,27 @@ sub try_push {
     return undef;
 }
 
+###########################################
+sub reset_key {
+###########################################
+    my ($self, %options) = @_;
+
+    my $key = $DEFAULT_KEY;
+    $key = $options{key} if defined $options{key};
+
+    DEBUG "Resetting $key";
+
+    my $total = 0;
+    for(0..$#{$self->{buckets}}) {
+        if (exists $self->{buckets}->[$_]->{count}->{$key}) {
+            $total += $self->{buckets}->[$_]->{count}->{$key};
+            $self->{buckets}->[$_]->{count}->{$key} = 0;
+        }
+    }
+
+    return $total;
+}
+
 ###########################################
 package Data::Throttler::Backend::Base;
 ###########################################
@@ -747,6 +791,15 @@ and
 
 to protect the data store against competing applications.
 
+=head2 RESETTING
+
+Sometimes, you may need to reset a specific counter, e.g. if an IP
+address has been unintentionally throttled:
+
+    my $count = $throttler->reset_key(key => "192.168.0.1");
+
+The C<reset_key> method returns the total number of attempts so far.
+
 =head2 ADVANCED USAGE
 
 By default, C<Data::Throttler> will decide on the number of buckets by 
